/*
 * Check whether the string is a date.
 */
import { __read, __spreadArray } from "tslib";
import { DAY, DELIMITER, HOUR, MILLISECOND, MINUTE, MONTH, OFFSET, SECOND, WEEK, WEEKDAY, YEAR, YEARDAY, } from './constants';
import { isString } from './isType';
/**
 * Get ISO 8601 date regular expression string array
 * Reference: https://www.cl.cam.ac.uk/~mgk25/iso-time.html
 * @param strict Require delimiter or not
 */
export function getIsoDatePatterns(strict) {
    if (strict === void 0) { strict = true; }
    return [
        // 1991
        "".concat(YEAR),
        // 1999-W12-7
        "".concat(YEAR).concat(DELIMITER).concat(strict ? '' : '?', "W").concat(WEEK, "(").concat(DELIMITER).concat(strict ? '' : '?').concat(WEEKDAY, ")?"),
        // 12-22-1999
        "".concat(MONTH).concat(DELIMITER).concat(strict ? '' : '?').concat(DAY).concat(DELIMITER).concat(strict ? '' : '?').concat(YEAR),
        // 1999-12-22 19991222
        "".concat(YEAR).concat(DELIMITER).concat(strict ? '' : '?').concat(MONTH).concat(DELIMITER).concat(strict ? '' : '?').concat(DAY),
        // 1999-12
        "".concat(YEAR).concat(DELIMITER).concat(strict ? '' : '?').concat(MONTH),
        // 1999-200
        "".concat(YEAR).concat(DELIMITER).concat(strict ? '' : '?').concat(YEARDAY),
    ];
}
/**
 * Get ISO 8601 time regular expression string array
 * Reference: https://www.cl.cam.ac.uk/~mgk25/iso-time.html
 * @param strict Require DELIMITER or not
 */
export function getIsoTimePatterns(strict) {
    if (strict === void 0) { strict = true; }
    return [
        // 23:20:20Z 23:20:20+08:00 23:20:20-08:00
        "".concat(HOUR, ":").concat(strict ? '' : '?').concat(MINUTE, ":").concat(strict ? '' : '?').concat(SECOND, "([.,]").concat(MILLISECOND, ")?").concat(OFFSET, "?"),
        // 23:20+08
        "".concat(HOUR, ":").concat(strict ? '' : '?').concat(MINUTE, "?").concat(OFFSET),
    ];
}
var getIsoDateAndTimeRegs = function (strictDatePattern) {
    var isoDatePatterns = getIsoDatePatterns(strictDatePattern);
    var isoTimePatterns = getIsoTimePatterns(strictDatePattern);
    var isoDateAndTimePatterns = __spreadArray(__spreadArray([], __read(isoDatePatterns), false), __read(isoTimePatterns), false);
    isoDatePatterns.forEach(function (d) {
        isoTimePatterns.forEach(function (t) {
            isoDateAndTimePatterns.push("".concat(d, "[T\\s]").concat(t));
        });
    });
    return isoDateAndTimePatterns.map(function (pattern) {
        return new RegExp("^".concat(pattern, "$"));
    });
};
export function isDateString(value, strictDatePattern) {
    if (isString(value)) {
        var isoDateAndTimeRegs = getIsoDateAndTimeRegs(strictDatePattern);
        for (var i = 0; i < isoDateAndTimeRegs.length; i += 1) {
            var reg = isoDateAndTimeRegs[i];
            if (reg.test(value.trim())) {
                return true;
            }
        }
    }
    return false;
}
