"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Advisor = void 0;
var ckb_1 = require("../ckb");
var ruler_1 = require("./ruler");
var advise_pipeline_1 = require("./advise-pipeline");
var check_rules_1 = require("./lint-pipeline/check-rules");
/*
 * 搬运计划
 * 0. 架构设计
 * 1. Advisor 搬运
 * 2. Linter 搬运
 */
var Advisor = /** @class */ (function () {
    function Advisor(config) {
        if (config === void 0) { config = {}; }
        this.ckb = (0, ckb_1.ckb)(config.ckbCfg);
        this.ruleBase = (0, ruler_1.processRuleCfg)(config.ruleCfg);
    }
    Advisor.prototype.advise = function (params) {
        var adviseResult = (0, advise_pipeline_1.advicesForChart)(params, this.ckb, this.ruleBase);
        return adviseResult.advices;
    };
    Advisor.prototype.adviseWithLog = function (params) {
        var adviseResult = (0, advise_pipeline_1.advicesForChart)(params, this.ckb, this.ruleBase);
        return adviseResult;
    };
    Advisor.prototype.lint = function (params) {
        var lintResult = (0, check_rules_1.checkRules)(params, this.ruleBase, this.ckb);
        return lintResult.lints;
    };
    Advisor.prototype.lintWithLog = function (params) {
        var lintResult = (0, check_rules_1.checkRules)(params, this.ruleBase, this.ckb);
        return lintResult;
    };
    return Advisor;
}());
exports.Advisor = Advisor;
