import type { StringFieldInfo, NumberFieldInfo, DateFieldInfo, FieldType } from '../../analysis/types';
/**
 * Array Type. One dimension or two dimension
 * @public
 */
export type NDArray = unknown[] | unknown[][];
/**
 * One dimension series data.
 * @public
 */
export type SeriesData = number | string | boolean | undefined | null | unknown[] | {
    [key: string]: unknown;
};
/**
 * One or two dimension frame data.
 * @public
 */
export type FrameData = number | string | boolean | undefined | null | unknown[] | {
    [key: string]: unknown;
} | unknown[][] | {
    [key: string]: unknown;
}[] | {
    [key: string]: unknown[];
};
/**
 * Axis
 * @public
 */
export type Axis = string | number;
/**
 * extra data configs
 * @public
 */
export type Extra = {
    indexes?: Axis[];
    columns?: Axis[];
    fillValue?: unknown;
    /** When the columnType is empty, no data type is specified */
    columnTypes?: (FieldType | '')[];
    /**
     * Whether only the main standard symbols recommended in ISO 8601 can be recognized as date fields, default is true.
     * - Reference: https://www.cl.cam.ac.uk/~mgk25/iso-time.html
     * - For example, '202301' is recognized as a date string only when strictDatePattern is false.
     * */
    strictDatePattern?: boolean;
};
/**
 * Fields Type
 * @public
 */
export type FieldsInfo = Array<(StringFieldInfo | NumberFieldInfo | DateFieldInfo) & {
    /** Field name */
    name: string;
}>;
