"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertDataType = exports.getStringifyLength = exports.stringify = exports.generateSplit = exports.fillMissingValue = exports.generateArrayIndex = exports.isAxis = void 0;
var utils_1 = require("../../utils");
function isAxis(value) {
    return (0, utils_1.isNumber)(value) || (0, utils_1.isString)(value);
}
exports.isAxis = isAxis;
// generate indexes for 1D and 2D array
function generateArrayIndex(data, extraIndex) {
    (0, utils_1.assert)((0, utils_1.isArray)(data), 'Data must be an array');
    if (extraIndex) {
        (0, utils_1.assert)((extraIndex === null || extraIndex === void 0 ? void 0 : extraIndex.length) === data.length, "Index length is ".concat(extraIndex === null || extraIndex === void 0 ? void 0 : extraIndex.length, ", but data size is ").concat(data.length));
        return extraIndex;
    }
    return (0, utils_1.range)(data.length);
}
exports.generateArrayIndex = generateArrayIndex;
function fillMissingValue(datum, fillValue) {
    return !datum && JSON.stringify(fillValue) ? fillValue : datum;
}
exports.fillMissingValue = fillMissingValue;
function generateSplit(length) {
    return Array((0, utils_1.isNumber)(length) ? length : 0)
        .fill(' ')
        .concat('  ')
        .join('');
}
exports.generateSplit = generateSplit;
function stringify(value) {
    var _a, _b, _c, _d, _e, _f;
    return (((_f = (_e = (_d = (_c = (_b = (_a = JSON.stringify(value)) === null || _a === void 0 ? void 0 : _a.replace(/\\n/g, '')) === null || _b === void 0 ? void 0 : _b.replace(/\\/g, '')) === null || _c === void 0 ? void 0 : _c.replace(/"\[/g, '[')) === null || _d === void 0 ? void 0 : _d.replace(/\]"/g, ']')) === null || _e === void 0 ? void 0 : _e.replace(/"\{/g, '{')) === null || _f === void 0 ? void 0 : _f.replace(/\}"/g, ' }')) || 'undefined');
}
exports.stringify = stringify;
function getStringifyLength(value) {
    var _a;
    return (_a = stringify(value)) === null || _a === void 0 ? void 0 : _a.length;
}
exports.getStringifyLength = getStringifyLength;
/**
 * Convert data to specified data type.
 * @param data
 * @param type
 */
function convertDataType(data, type) {
    try {
        if (type === 'string' && !(0, utils_1.isString)(data)) {
            return "".concat(data);
        }
        if (type === 'boolean' && !(0, utils_1.isBoolean)(data)) {
            return Boolean(data);
        }
        if (type === 'null' && !(0, utils_1.isNil)(data)) {
            return null;
        }
        if ((type === 'integer' || type === 'float') && !(0, utils_1.isNumber)(data)) {
            return +data;
        }
        if (type === 'date' && !(0, utils_1.isDate)(data) && ((0, utils_1.isNumber)(data) || (0, utils_1.isString)(data))) {
            return new Date(data);
        }
    }
    catch (error) {
        throw new Error(error);
    }
    return data;
}
exports.convertDataType = convertDataType;
