"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isParentChild = exports.assert = exports.nZeros = exports.nOnes = exports.range = exports.unique = void 0;
var tslib_1 = require("tslib");
var isType_1 = require("./isType");
/**
 * Return an array with unique elements
 * @param value
 */
function unique(value) {
    return Array.from(new Set(value));
}
exports.unique = unique;
/**
 * Generate an array from 0 to number.
 * @param number
 */
function range(number) {
    return tslib_1.__spreadArray([], tslib_1.__read(Array(number).keys()), false);
}
exports.range = range;
/** Generate an array with all 1 elements */
function nOnes(n) {
    return Array(n).fill(1);
}
exports.nOnes = nOnes;
/** Generate an array with all 0 elements */
function nZeros(n) {
    return Array(n).fill(0);
}
exports.nZeros = nZeros;
/**
 * assert
 * @param condition
 * @param errorMessage
 */
function assert(condition, errorMessage) {
    if (!condition)
        throw new Error(errorMessage);
}
exports.assert = assert;
/**
 * Check parent-child relationship. A child has only one parent, but a parent can have more children.
 * @param parent
 * @param child
 */
function isParentChild(parent, child) {
    if (!(0, isType_1.isArray)(parent) ||
        parent.length === 0 ||
        !(0, isType_1.isArray)(child) ||
        child.length === 0 ||
        parent.length !== child.length)
        return false;
    var record = {};
    for (var i = 0; i < child.length; i += 1) {
        var c = child[i];
        var p = parent[i];
        if (!record[c]) {
            record[c] = p;
        }
        else if (record[c] !== p) {
            return false;
        }
    }
    return true;
}
exports.isParentChild = isParentChild;
