"use strict";
/*
 * Check whether the string is a date.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.isDateString = exports.getIsoTimePatterns = exports.getIsoDatePatterns = void 0;
var tslib_1 = require("tslib");
var constants_1 = require("./constants");
var isType_1 = require("./isType");
/**
 * Get ISO 8601 date regular expression string array
 * Reference: https://www.cl.cam.ac.uk/~mgk25/iso-time.html
 * @param strict Require delimiter or not
 */
function getIsoDatePatterns(strict) {
    if (strict === void 0) { strict = true; }
    return [
        // 1991
        "".concat(constants_1.YEAR),
        // 1999-W12-7
        "".concat(constants_1.YEAR).concat(constants_1.DELIMITER).concat(strict ? '' : '?', "W").concat(constants_1.WEEK, "(").concat(constants_1.DELIMITER).concat(strict ? '' : '?').concat(constants_1.WEEKDAY, ")?"),
        // 12-22-1999
        "".concat(constants_1.MONTH).concat(constants_1.DELIMITER).concat(strict ? '' : '?').concat(constants_1.DAY).concat(constants_1.DELIMITER).concat(strict ? '' : '?').concat(constants_1.YEAR),
        // 1999-12-22 19991222
        "".concat(constants_1.YEAR).concat(constants_1.DELIMITER).concat(strict ? '' : '?').concat(constants_1.MONTH).concat(constants_1.DELIMITER).concat(strict ? '' : '?').concat(constants_1.DAY),
        // 1999-12
        "".concat(constants_1.YEAR).concat(constants_1.DELIMITER).concat(strict ? '' : '?').concat(constants_1.MONTH),
        // 1999-200
        "".concat(constants_1.YEAR).concat(constants_1.DELIMITER).concat(strict ? '' : '?').concat(constants_1.YEARDAY),
    ];
}
exports.getIsoDatePatterns = getIsoDatePatterns;
/**
 * Get ISO 8601 time regular expression string array
 * Reference: https://www.cl.cam.ac.uk/~mgk25/iso-time.html
 * @param strict Require DELIMITER or not
 */
function getIsoTimePatterns(strict) {
    if (strict === void 0) { strict = true; }
    return [
        // 23:20:20Z 23:20:20+08:00 23:20:20-08:00
        "".concat(constants_1.HOUR, ":").concat(strict ? '' : '?').concat(constants_1.MINUTE, ":").concat(strict ? '' : '?').concat(constants_1.SECOND, "([.,]").concat(constants_1.MILLISECOND, ")?").concat(constants_1.OFFSET, "?"),
        // 23:20+08
        "".concat(constants_1.HOUR, ":").concat(strict ? '' : '?').concat(constants_1.MINUTE, "?").concat(constants_1.OFFSET),
    ];
}
exports.getIsoTimePatterns = getIsoTimePatterns;
var getIsoDateAndTimeRegs = function (strictDatePattern) {
    var isoDatePatterns = getIsoDatePatterns(strictDatePattern);
    var isoTimePatterns = getIsoTimePatterns(strictDatePattern);
    var isoDateAndTimePatterns = tslib_1.__spreadArray(tslib_1.__spreadArray([], tslib_1.__read(isoDatePatterns), false), tslib_1.__read(isoTimePatterns), false);
    isoDatePatterns.forEach(function (d) {
        isoTimePatterns.forEach(function (t) {
            isoDateAndTimePatterns.push("".concat(d, "[T\\s]").concat(t));
        });
    });
    return isoDateAndTimePatterns.map(function (pattern) {
        return new RegExp("^".concat(pattern, "$"));
    });
};
function isDateString(value, strictDatePattern) {
    if ((0, isType_1.isString)(value)) {
        var isoDateAndTimeRegs = getIsoDateAndTimeRegs(strictDatePattern);
        for (var i = 0; i < isoDateAndTimeRegs.length; i += 1) {
            var reg = isoDateAndTimeRegs[i];
            if (reg.test(value.trim())) {
                return true;
            }
        }
    }
    return false;
}
exports.isDateString = isDateString;
