"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.timeSeriesOutlierStrategy = exports.timeSeriesOutlierStrategyAugmentedMarksStrategy = void 0;
var tslib_1 = require("tslib");
var chart_1 = require("../chart");
var commonMarks_1 = require("../commonMarks");
var BASELINE = 'baseline';
var INTERVAL = 'interval';
var OUTLIER = 'outlier';
var timeSeriesOutlierStrategyAugmentedMarksStrategy = function (insight) {
    var chartData = insight.data, _a = tslib_1.__read(insight.dimensions, 1), dimensionName = _a[0].fieldName, patterns = insight.patterns;
    var _b = patterns[0], baselines = _b.baselines, thresholds = _b.thresholds;
    var data = chartData.map(function (datum, index) {
        var baseline = baselines[index];
        var interval = [baseline - Math.abs(thresholds[0]), baseline + thresholds[1]];
        return {
            baseline: {
                x: datum[dimensionName],
                y: baseline,
            },
            interval: {
                x: datum[dimensionName],
                y: interval,
            },
        };
    });
    var intervalData = data.map(function (datum) { return datum[INTERVAL]; });
    var intervalMark = (0, commonMarks_1.areaMarkStrategy)(intervalData, {
        encode: {
            shape: 'smooth',
        },
        style: {
            fillOpacity: 0.3,
            fill: '#ffd8b8',
        },
        tooltip: {
            title: '',
            items: [
                function (_d, i, _data, column) { return ({
                    name: INTERVAL,
                    value: "".concat(column.y.value[i], "-").concat(column.y1.value[i]),
                    color: '#ffd8b8',
                }); },
            ],
        },
    });
    var baselineData = data.map(function (datum) { return datum[BASELINE]; });
    var baselineMark = (0, commonMarks_1.lineMarkStrategy)({ points: baselineData }, {
        encode: {
            shape: 'smooth',
        },
        style: {
            lineWidth: 1,
            stroke: '#ffa45c',
            lineDash: undefined,
        },
        tooltip: {
            title: '',
            items: [{ name: BASELINE, channel: 'y' }],
        },
    });
    var outlierMark = (0, commonMarks_1.pointMarkStrategy)(patterns, {
        style: {
            fill: '#f4664a',
            stroke: '#f4664a',
        },
        tooltip: {
            title: '',
            items: [{ name: OUTLIER, channel: 'y' }],
        },
    });
    return [intervalMark, baselineMark, outlierMark];
};
exports.timeSeriesOutlierStrategyAugmentedMarksStrategy = timeSeriesOutlierStrategyAugmentedMarksStrategy;
var timeSeriesOutlierStrategy = function (insight) {
    var _a;
    // Should to support marks free combination
    var chartMark = (0, chart_1.insight2ChartStrategy)(insight);
    var augmentedMarks = (_a = (0, exports.timeSeriesOutlierStrategyAugmentedMarksStrategy)(insight)) === null || _a === void 0 ? void 0 : _a.slice();
    augmentedMarks.splice(2, 0, chartMark);
    return augmentedMarks;
};
exports.timeSeriesOutlierStrategy = timeSeriesOutlierStrategy;
