"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCategoryOutlierInfo = exports.findOutliers = void 0;
var tslib_1 = require("tslib");
var lodash_1 = require("lodash");
var data_1 = require("../../../data");
var algorithms_1 = require("../../algorithms");
var constant_1 = require("../../constant");
var util_1 = require("../util");
var findOutliers = function (values, outlierParameter) {
    var _a = outlierParameter || {}, method = _a.method, iqrK = _a.iqrK, _b = _a.confidenceInterval, confidenceInterval = _b === void 0 ? constant_1.SIGNIFICANCE_BENCHMARK : _b;
    var outliers = [];
    var thresholds = [];
    var candidates = values.map(function (item, index) {
        return { index: index, value: item };
    });
    if (method !== 'p-value') {
        var IQRResult = algorithms_1.categoryOutlier.IQR(values, { k: iqrK !== null && iqrK !== void 0 ? iqrK : constant_1.IQR_K });
        var lowerOutlierIndexes = IQRResult.lower.indexes;
        var upperOutlierIndexes = IQRResult.upper.indexes;
        tslib_1.__spreadArray(tslib_1.__spreadArray([], tslib_1.__read(lowerOutlierIndexes), false), tslib_1.__read(upperOutlierIndexes), false).forEach(function (index) {
            var value = values[index];
            var pValue = (candidates.findIndex(function (item) { return item.value === value; }) + 1) / values.length;
            // two-sided
            var significance = pValue > 0.5 ? pValue : 1 - pValue;
            outliers.push({
                index: index,
                value: value,
                significance: significance,
            });
        });
        thresholds.push(IQRResult.lower.threshold, IQRResult.upper.threshold);
    }
    else {
        var sortedCandidates = (0, lodash_1.orderBy)(candidates, function (item) { return Math.abs((0, data_1.mean)(values) - item.value); }, ['desc']);
        thresholds.push.apply(thresholds, tslib_1.__spreadArray([], tslib_1.__read((0, util_1.calculateOutlierThresholds)(values, confidenceInterval, 'two-sided')), false));
        for (var i = 0; i < sortedCandidates.length; i += 1) {
            var candidate = sortedCandidates[i];
            var value = candidate.value, index = candidate.index;
            var pValue = (0, util_1.calculatePValue)(values, value, 'two-sided');
            var significance = 1 - pValue;
            if (significance < confidenceInterval) {
                break;
            }
            outliers.push({
                index: index,
                value: value,
                significance: significance,
            });
        }
    }
    return { outliers: outliers, thresholds: thresholds };
};
exports.findOutliers = findOutliers;
var getCategoryOutlierInfo = function (props) {
    var valid = (0, util_1.preValidation)(props);
    var insightType = 'category_outlier';
    if ((0, lodash_1.isString)(valid))
        return (0, util_1.getNonSignificantInsight)({ detailInfo: valid, insightType: insightType, infoType: 'verificationFailure' });
    var _a = (0, util_1.getAlgorithmCommonInput)(props), dimension = _a.dimension, values = _a.values, measure = _a.measure;
    if ((0, data_1.distinct)(values) === 1)
        return (0, util_1.getNonSignificantInsight)({
            insightType: insightType,
            infoType: 'noInsight',
            customInfo: { info: 'Each value in the data is the same. No outliers were found.' },
        });
    var data = props.data;
    var outlierParameter = (0, lodash_1.get)(props, 'options.algorithmParameter.outlier');
    var outliers = (0, exports.findOutliers)(values, outlierParameter).outliers;
    if (outliers.length === 0) {
        var info = "No outliers were found using method ".concat((outlierParameter === null || outlierParameter === void 0 ? void 0 : outlierParameter.method) !== 'p-value' ? 'Inter Quartile Range' : 'Normal Distribution test', ".");
        return (0, util_1.getNonSignificantInsight)({ insightType: insightType, infoType: 'noInsight', customInfo: { info: info } });
    }
    var categoryOutliers = outliers.map(function (item) {
        var index = item.index, significance = item.significance;
        return {
            type: insightType,
            dimension: dimension,
            measure: measure,
            significance: significance,
            index: index,
            x: data[index][dimension],
            y: data[index][measure],
            significantInsight: true,
        };
    });
    return categoryOutliers;
};
exports.getCategoryOutlierInfo = getCategoryOutlierInfo;
