"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMajorityInfo = exports.findMajority = void 0;
var lodash_1 = require("lodash");
var util_1 = require("../util");
var DEFAULT_PROPORTION_LIMIT = 0.6;
function findMajority(values, majorityParameter) {
    var sum = 0;
    var max = -Infinity;
    var maxIndex = -1;
    for (var i = 0; i < (values === null || values === void 0 ? void 0 : values.length); i += 1) {
        sum += values[i];
        if (values[i] > max) {
            max = values[i];
            maxIndex = i;
        }
    }
    var proportionLimit = (majorityParameter === null || majorityParameter === void 0 ? void 0 : majorityParameter.limit) || DEFAULT_PROPORTION_LIMIT;
    if (sum === 0)
        return null;
    var proportion = max / sum;
    if (proportion > proportionLimit && proportion < 1) {
        return {
            index: maxIndex,
            value: max,
            proportion: proportion,
            significance: proportion,
        };
    }
    return null;
}
exports.findMajority = findMajority;
var getMajorityInfo = function (props) {
    var valid = (0, util_1.preValidation)(props);
    var insightType = 'majority';
    if ((0, lodash_1.isString)(valid))
        return (0, util_1.getNonSignificantInsight)({ detailInfo: valid, insightType: insightType, infoType: 'verificationFailure' });
    var data = props.data;
    var _a = (0, util_1.getAlgorithmCommonInput)(props), dimension = _a.dimension, values = _a.values, measure = _a.measure;
    var majorityParameter = (0, lodash_1.get)(props, 'options.algorithmParameter.majority');
    var majority = findMajority(values, majorityParameter);
    if (majority) {
        var significance = majority.significance, index = majority.index, proportion = majority.proportion;
        return [
            {
                type: insightType,
                dimension: dimension,
                measure: measure,
                significance: significance,
                index: index,
                proportion: proportion,
                x: data[index][dimension],
                y: data[index][measure],
                significantInsight: true,
            },
        ];
    }
    var info = "After disassembling with the given dimension, the proportion of the maximum value does not exceed ".concat((majorityParameter === null || majorityParameter === void 0 ? void 0 : majorityParameter.limit) || DEFAULT_PROPORTION_LIMIT, ".");
    return (0, util_1.getNonSignificantInsight)({
        insightType: insightType,
        infoType: 'noInsight',
        customInfo: { info: info, dimension: dimension, measure: measure },
    });
};
exports.getMajorityInfo = getMajorityInfo;
