"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTimeSeriesOutlierInfo = void 0;
var lodash_1 = require("lodash");
var data_1 = require("../../../data");
var constant_1 = require("../../constant");
var util_1 = require("../util");
var categoryOutlier_1 = require("./categoryOutlier");
// detect the outliers using LOWESS
function findTimeSeriesOutliers(values, outlierParameter) {
    var indexes = Array(values.length)
        .fill(0)
        .map(function (_, index) { return index; });
    var baseline = (0, data_1.lowess)(indexes, values, { nSteps: constant_1.LOWESS_N_STEPS });
    var residuals = values.map(function (item, index) { return item - baseline.y[index]; });
    var _a = (0, categoryOutlier_1.findOutliers)(residuals, outlierParameter), outliers = _a.outliers, thresholds = _a.thresholds;
    return { outliers: outliers, baselines: baseline.y, thresholds: thresholds };
}
var getTimeSeriesOutlierInfo = function (props) {
    var valid = (0, util_1.preValidation)(props);
    var insightType = 'time_series_outlier';
    if ((0, lodash_1.isString)(valid))
        return (0, util_1.getNonSignificantInsight)({ detailInfo: valid, insightType: insightType, infoType: 'verificationFailure' });
    var data = props.data;
    var _a = (0, util_1.getAlgorithmCommonInput)(props), dimension = _a.dimension, values = _a.values, measure = _a.measure;
    if ((0, data_1.distinct)(values) === 1)
        return (0, util_1.getNonSignificantInsight)({ insightType: insightType, infoType: 'noInsight' });
    var outlierParameter = (0, lodash_1.get)(props, 'options.algorithmParameter.outlier');
    var _b = findTimeSeriesOutliers(values, outlierParameter), outliers = _b.outliers, baselines = _b.baselines, thresholds = _b.thresholds;
    if (outliers.length === 0)
        return (0, util_1.getNonSignificantInsight)({
            insightType: insightType,
            infoType: 'noInsight',
            customInfo: {
                baselines: baselines,
                thresholds: thresholds,
                dimension: dimension,
                measure: measure,
                info: 'No outliers were found.',
            },
        });
    var timeSeriesOutliers = outliers.map(function (item) {
        var index = item.index, significance = item.significance;
        return {
            type: insightType,
            dimension: dimension,
            measure: measure,
            significance: significance,
            index: index,
            x: data[index][dimension],
            y: data[index][measure],
            baselines: baselines,
            thresholds: thresholds,
            significantInsight: true,
        };
    });
    return timeSeriesOutliers;
};
exports.getTimeSeriesOutlierInfo = getTimeSeriesOutlierInfo;
