"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pickValidPattern = exports.getNonSignificantInsight = exports.preValidation = exports.getAlgorithmCommonInput = exports.calculateOutlierThresholds = exports.calculatePValue = void 0;
var tslib_1 = require("tslib");
var lodash_1 = require("lodash");
var data_1 = require("../../data");
var preprocess_1 = require("../pipeline/preprocess");
var constant_1 = require("../constant");
var checkers_1 = require("./checkers");
var calculatePValue = function (values, target, alternative) {
    if (alternative === void 0) { alternative = 'two-sided'; }
    var meanValue = (0, lodash_1.mean)(values);
    var std = (0, data_1.standardDeviation)(values);
    var cdfValue = (0, data_1.cdf)(target, meanValue, std);
    if (alternative === 'two-sided')
        return cdfValue < 0.5 ? 2 * cdfValue : 2 * (1 - cdfValue);
    if (alternative === 'less')
        return cdfValue;
    return 1 - cdfValue;
};
exports.calculatePValue = calculatePValue;
var calculateOutlierThresholds = function (values, significance, alternative) {
    if (alternative === void 0) { alternative = 'two-sided'; }
    var meanValue = (0, lodash_1.mean)(values);
    var std = (0, data_1.standardDeviation)(values);
    var p = 1 - significance;
    if (alternative === 'greater')
        return [(0, data_1.normalDistributionQuantile)(significance, meanValue, std), (0, data_1.max)(values)];
    if (alternative === 'less')
        return [(0, data_1.min)(values), (0, data_1.normalDistributionQuantile)(p, meanValue, std)];
    return [
        (0, data_1.normalDistributionQuantile)(p / 2, meanValue, std),
        (0, data_1.normalDistributionQuantile)(significance + p / 2, meanValue, std),
    ];
};
exports.calculateOutlierThresholds = calculateOutlierThresholds;
var getAlgorithmCommonInput = function (_a) {
    var data = _a.data, dimensions = _a.dimensions, measures = _a.measures;
    var dimension = dimensions[0];
    var measure = measures[0].fieldName;
    var values = data.map(function (item) { return item === null || item === void 0 ? void 0 : item[measure]; });
    return { dimension: dimension, measure: measure, values: values };
};
exports.getAlgorithmCommonInput = getAlgorithmCommonInput;
var preValidation = function (_a) {
    var data = _a.data, dimensions = _a.dimensions, measures = _a.measures, options = _a.options, insightType = _a.insightType;
    var _b = options || {}, _c = _b.dataValidation, dataValidation = _c === void 0 ? false : _c, dataProcessInfo = _b.dataProcessInfo;
    if (!data || data.length === 0)
        return 'No data. ';
    if (!dataValidation)
        return true;
    var filteredData = data.filter(function (item) { return !Object.values(item).some(function (v) { return v === null || v === undefined; }); });
    var dataProps = (0, preprocess_1.dataToDataProps)(filteredData, dataProcessInfo);
    var fieldPropsMap = dataProps.reduce(function (acc, item) {
        acc[item.name] = item;
        return acc;
    }, {});
    var checker = checkers_1.ExtractorCheckers[insightType];
    if (!checker)
        return true;
    var result = checker({
        data: data,
        subjectInfo: { dimensions: dimensions, measures: measures, subspace: [] },
        fieldPropsMap: fieldPropsMap,
    });
    return result;
};
exports.preValidation = preValidation;
var getNonSignificantInsight = function (_a) {
    var infoType = _a.infoType, insightType = _a.insightType, _b = _a.detailInfo, detailInfo = _b === void 0 ? '' : _b, _c = _a.customInfo, customInfo = _c === void 0 ? {} : _c;
    var info = "".concat(detailInfo).concat(infoType === 'noInsight' ? constant_1.NO_PATTERN_INFO : constant_1.VERIFICATION_FAILURE_INFO);
    return [
        tslib_1.__assign({ significantInsight: false, type: insightType, info: info, significance: 0 }, customInfo),
    ];
};
exports.getNonSignificantInsight = getNonSignificantInsight;
var pickValidPattern = function (infos) {
    if (infos === void 0) { infos = []; }
    return infos.filter(function (info) { return info.significantInsight; });
};
exports.pickValidPattern = pickValidPattern;
