"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/* eslint-disable no-template-curly-in-string */
var lodash_1 = require("lodash");
var ntv_1 = require("../../../ntv");
var base_1 = require("./base");
var trendMapping = {
    decreasing: '下降',
    increasing: '上升',
    'no trend': '无明显趋势。',
};
var variableMetaMap = {
    dateRange: {
        varType: 'time_desc',
    },
    trend: {
        varType: 'trend_desc',
    },
    measure: {
        varType: 'metric_name',
    },
};
var TrendNarrativeStrategy = /** @class */ (function (_super) {
    tslib_1.__extends(TrendNarrativeStrategy, _super);
    function TrendNarrativeStrategy() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TrendNarrativeStrategy.prototype.generateTextSpec = function (insightInfo, lang) {
        var patterns = insightInfo.patterns, data = insightInfo.data;
        var _a = patterns[0], dimension = _a.dimension, measure = _a.measure, trend = _a.trend;
        var spec = (0, ntv_1.generateTextSpec)({
            structures: TrendNarrativeStrategy.structures[lang],
            variable: {
                dateRange: "".concat((0, lodash_1.first)(data)[dimension], "~").concat((0, lodash_1.last)(data)[dimension]),
                measure: measure,
                trend: lang === 'en-US' ? trend : trendMapping[trend],
            },
        });
        return spec.sections[0].paragraphs;
    };
    TrendNarrativeStrategy.insightType = 'trend';
    TrendNarrativeStrategy.structures = {
        'zh-CN': [
            {
                template: '${dateRange}，${measure}${trend}。',
                variableMetaMap: variableMetaMap,
            },
        ],
        'en-US': [
            {
                template: 'In ${dateRange}, the ${measure} goes ${trend}.',
                variableMetaMap: variableMetaMap,
            },
        ],
    };
    return TrendNarrativeStrategy;
}(base_1.InsightNarrativeStrategy));
exports.default = TrendNarrativeStrategy;
