import { Variable } from '../generate/types';
import { CustomMetaData, CommonProps } from './common';
export type PhraseSpec = TextPhraseSpec | EntityPhraseSpec | EscapePhraseSpec | FormulaPhraseSpec | CustomPhraseSpec<CustomMetaData>;
export type TextPhraseSpec = CommonProps & {
    type: 'text';
    value: string;
    bold?: boolean;
    italic?: boolean;
    underline?: boolean;
    url?: string;
};
/**
 * escape character 支持转义字符
 */
export type EscapePhraseSpec = CommonProps & {
    type: 'escape';
    value: string;
};
/**
 * math formula
 */
export type FormulaPhraseSpec = CommonProps & {
    type: 'formula';
    value: string;
};
export type EntityPhraseSpec = CommonProps & {
    type: 'entity';
    value?: string;
    metadata?: EntityMetaData;
};
export type CustomPhraseSpec<P extends CustomMetaData = CustomMetaData> = CommonProps & {
    type: 'custom';
    value?: string;
    metadata?: P;
};
export type ValueAssessment = 'positive' | 'negative' | 'equal';
export declare const ENTITY_TYPES: readonly ["metric_name", "metric_value", "other_metric_value", "contribute_ratio", "delta_value", "ratio_value", "trend_desc", "dim_value", "time_desc", "proportion"];
export type EntityType = (typeof ENTITY_TYPES)[number];
export type EntityMetaData = {
    /**
     * entity type, 实体类型标记
     * */
    entityType: EntityType;
    /**
     * assessment up or down, used for derived value
     * 衍生指标评估参数，指定上涨或者下跌
     * */
    assessment?: ValueAssessment;
    /**
     * original data, 原始数据
     * */
    origin?: number;
    /**
     * detail data, 明细数据，用于弹框展示
     */
    detail?: unknown;
    /** source id of the variable, to access the variable info from variableSourceMap */
    /**
     * generate variable info, 通过模版拼接工具函数生成过程中得到的变量信息
     */
    generateVariableInfo?: {
        scopeVariable: Variable;
        path: string;
    };
};
