"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isFormulaPhrase = exports.isEscapePhrase = exports.isTextPhrase = exports.isEntityPhrase = exports.isEntityType = exports.isCustomPhrase = exports.isHeadingParagraph = exports.getHeadingWeight = exports.isBulletParagraph = exports.isTextParagraph = exports.isStandardSection = exports.isCustomParagraph = exports.isCustomSection = void 0;
var utils_1 = require("../../utils");
var schema_1 = require("../schema");
function isCustomSection(spec) {
    return (0, utils_1.isObject)(spec) && 'customType' in spec;
}
exports.isCustomSection = isCustomSection;
function isCustomParagraph(spec) {
    return (0, utils_1.isObject)(spec) && 'customType' in spec;
}
exports.isCustomParagraph = isCustomParagraph;
function isStandardSection(spec) {
    return (0, utils_1.isObject)(spec) && 'paragraphs' in spec && Array.isArray(spec === null || spec === void 0 ? void 0 : spec.paragraphs);
}
exports.isStandardSection = isStandardSection;
function isTextParagraph(spec) {
    return (0, utils_1.isObject)(spec) && (spec === null || spec === void 0 ? void 0 : spec.type) === 'normal' && Array.isArray(spec === null || spec === void 0 ? void 0 : spec.phrases);
}
exports.isTextParagraph = isTextParagraph;
function isBulletParagraph(spec) {
    return (0, utils_1.isObject)(spec) && (spec === null || spec === void 0 ? void 0 : spec.type) === 'bullets' && Array.isArray(spec === null || spec === void 0 ? void 0 : spec.bullets);
}
exports.isBulletParagraph = isBulletParagraph;
function getHeadingWeight(pType) {
    if (pType === null || pType === void 0 ? void 0 : pType.startsWith('heading')) {
        var weight = Number(pType === null || pType === void 0 ? void 0 : pType.slice(-1));
        if (weight >= 1 && weight <= 6)
            return weight;
    }
    return NaN;
}
exports.getHeadingWeight = getHeadingWeight;
function isHeadingParagraph(spec) {
    if ((0, utils_1.isObject)(spec) && 'type' in spec && (0, utils_1.isString)(spec.type)) {
        var weight = getHeadingWeight(spec === null || spec === void 0 ? void 0 : spec.type);
        return spec.type.startsWith('heading') && !Number.isNaN(weight);
    }
    return false;
}
exports.isHeadingParagraph = isHeadingParagraph;
function isCustomPhrase(spec) {
    var _a;
    return (spec === null || spec === void 0 ? void 0 : spec.type) === 'custom' && !!((_a = spec === null || spec === void 0 ? void 0 : spec.metadata) === null || _a === void 0 ? void 0 : _a.customType);
}
exports.isCustomPhrase = isCustomPhrase;
function isEntityType(type) {
    return schema_1.ENTITY_TYPES.includes(type);
}
exports.isEntityType = isEntityType;
function isEntityPhrase(spec) {
    var _a;
    return (spec === null || spec === void 0 ? void 0 : spec.type) === 'entity' && schema_1.ENTITY_TYPES.includes((_a = spec === null || spec === void 0 ? void 0 : spec.metadata) === null || _a === void 0 ? void 0 : _a.entityType);
}
exports.isEntityPhrase = isEntityPhrase;
function isTextPhrase(spec) {
    return (spec === null || spec === void 0 ? void 0 : spec.type) === 'text';
}
exports.isTextPhrase = isTextPhrase;
function isEscapePhrase(spec) {
    return (spec === null || spec === void 0 ? void 0 : spec.type) === 'escape';
}
exports.isEscapePhrase = isEscapePhrase;
function isFormulaPhrase(spec) {
    return (spec === null || spec === void 0 ? void 0 : spec.type) === 'formula';
}
exports.isFormulaPhrase = isFormulaPhrase;
